"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const uriTemplate = require("uri-template");
const url_1 = require("./utils/url");
/**
 * The Link object represents a hyperlink.
 */
class Link {
    constructor(properties) {
        this.templated = false;
        this.title = null;
        this.type = null;
        for (const key of ['context', 'href', 'name', 'rel', 'templated', 'title', 'type']) {
            if (properties[key]) {
                this[key] = properties[key];
            }
        }
    }
    /**
     * Returns the absolute link url, based on it's base and relative url.
     */
    resolve() {
        return url_1.resolve(this.context, this.href);
    }
    /**
     * Expands a link template (RFC6570) and resolves the uri
     *
     * @param {object} variables - A list of variables to expand the link with.
     * @returns {string}
     */
    expand(variables) {
        if (!this.templated) {
            return url_1.resolve(this.context, this.href);
        }
        else {
            const templ = uriTemplate.parse(this.href);
            const expanded = templ.expand(variables);
            return url_1.resolve(this.context, expanded);
        }
    }
}
exports.default = Link;
//# sourceMappingURL=link.js.map