"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const link_1 = require("../link");
const url_1 = require("../utils/url");
const base_1 = require("./base");
/**
 * The Representation class is basically a 'body' of a request
 * or response.
 *
 * This class is for Siren responses.
 *
 * https://github.com/kevinswiber/siren
 */
class Siren extends base_1.default {
    parse(body) {
        return JSON.parse(body);
    }
    parseLinks(body) {
        const result = [];
        if (body.links !== undefined) {
            for (const link of body.links) {
                result.push(...parseSirenLink(this.uri, link));
            }
        }
        if (body.entities !== undefined) {
            for (const subEntity of body.entities) {
                if (subEntity.href !== undefined) {
                    result.push(...parseSirenLink(this.uri, subEntity));
                }
                else {
                    result.push(...parseSirenSubEntityAsLink(this.uri, subEntity));
                }
            }
        }
        return result;
    }
    getEmbedded() {
        if (this.body.entities === undefined) {
            return {};
        }
        const result = {};
        for (const entity of this.body.entities) {
            if (entity.href === undefined) {
                const embedded = parseSirenSubEntityAsEmbedded(this.uri, entity);
                if (embedded !== null) {
                    result[embedded[0]] = embedded[1];
                }
            }
        }
        return result;
    }
}
exports.default = Siren;
function parseSirenLink(contextUri, link) {
    const result = [];
    for (const rel of link.rel) {
        result.push(new link_1.default({
            href: link.href,
            rel,
            title: link.title,
            type: link.type,
            context: contextUri,
        }));
    }
    return result;
}
function parseSirenSubEntityAsLink(contextUri, subEntity) {
    if (subEntity.links === undefined) {
        // We don't yet support subentities that don't have a URI.
        return [];
    }
    let selfHref = null;
    for (const link of subEntity.links) {
        if (link.rel.includes('self')) {
            selfHref = link.href;
        }
    }
    if (selfHref === null) {
        // We don't yet support subentities that don't have a URI.
        return [];
    }
    return subEntity.rel.map(rel => {
        return new link_1.default({
            href: selfHref,
            rel,
            title: subEntity.title,
            context: contextUri,
        });
    });
}
function parseSirenSubEntityAsEmbedded(contextUri, subEntity) {
    if (subEntity.links === undefined) {
        // We don't yet support subentities that don't have a URI.
        return null;
    }
    let selfHref = null;
    for (const link of subEntity.links) {
        if (link.rel.includes('self')) {
            selfHref = link.href;
        }
    }
    if (!selfHref) {
        // We don't yet support subentities that don't have a URI.
        return null;
    }
    return [url_1.resolve(contextUri, selfHref), subEntity];
}
//# sourceMappingURL=siren.js.map