import Link from '../link';
import Representation from './base';
declare type SirenEntity = {
    class?: string[];
    properties?: {
        [key: string]: any;
    };
    entities?: Array<SirenLink | SirenSubEntity>;
    links?: SirenLink[];
    actions?: SirenAction[];
    title?: string;
};
declare type SirenSubEntity = SirenEntity & {
    rel: string[];
};
declare type SirenLink = {
    class?: string[];
    rel: string[];
    href: string;
    type?: string;
    title?: string;
};
declare type SirenAction = {
    name: string;
    class?: string[];
    method?: string;
    href: string;
    title?: string;
    type?: string;
    fields?: SirenField[];
};
declare type SirenField = {
    name: string;
    class?: string[];
    type?: 'hidden' | 'text' | 'search' | 'tel' | 'url' | 'email' | 'password' | 'datetime' | 'date' | 'month' | 'week' | 'time' | 'datetime-local' | 'number' | 'range' | 'color' | 'checkbox' | 'radio' | 'file';
    value?: string;
    title?: string;
};
/**
 * The Representation class is basically a 'body' of a request
 * or response.
 *
 * This class is for Siren responses.
 *
 * https://github.com/kevinswiber/siren
 */
export default class Siren extends Representation<SirenEntity> {
    parse(body: string): SirenEntity;
    parseLinks(body: SirenEntity): Link[];
    getEmbedded(): {
        [uri: string]: SirenEntity;
    };
}
export {};
