"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fetch_mw_oauth2_1 = require("fetch-mw-oauth2");
require("./fetch-polyfill");
class OAuth2Helper {
    constructor(options) {
        let oauth2Options;
        if (isOldOptionsFormat(options)) {
            // These are the 'old style' settings and exist for compatibility
            if (options.owner) {
                oauth2Options = {
                    grantType: 'password',
                    tokenEndpoint: options.client.accessTokenUri,
                    clientId: options.client.clientId,
                    clientSecret: options.client.clientSecret,
                    userName: options.owner.userName,
                    password: options.owner.password,
                };
            }
            else {
                oauth2Options = {
                    grantType: 'client_credentials',
                    tokenEndpoint: options.client.accessTokenUri,
                    clientId: options.client.clientId,
                    clientSecret: options.client.clientSecret,
                };
            }
        }
        else {
            // New setting format
            oauth2Options = options;
        }
        this.oauth2 = new fetch_mw_oauth2_1.OAuth2(oauth2Options);
    }
    /**
     * Does a HTTP request with OAuth2 enabled.
     *
     * This function will automatically grab an access token if it didn't have
     * one, and attempt to refresh the token if it was expired.
     */
    async fetch(request) {
        return this.oauth2.fetch(request);
    }
}
exports.OAuth2Helper = OAuth2Helper;
function isOldOptionsFormat(options) {
    return options.client !== undefined;
}
//# sourceMappingURL=oauth.js.map